@@ -582,4 +582,87 @@ class AMIProtocolTestCase(unittest.TestCase):
         channel.dialBegun.assert_called_once_with('Bar/303-0', None)
 
 
+    def test_channelReloadDistribution(self):
+        """ChannelReload event called on AMIProtocol"""
+
+        channel = self._startAndSpawnChannel()
+        cbEvent = self.protocol.event_channelreload = Mock()
+        lose = self.transport.loseConnection = Mock()
+
+        self.protocol.dataReceived(
+            'Event: ChannelReload\r\n'
+            'Channel: SIP\r\n'
+            'ReloadReason: RELOAD (Channel module reload)\r\n'
+            'Registry_Count: 0\r\n'
+            'Peer_Count: 0\r\n'
+            'User_Count: 0\r\n'
+            '\r\n'
+        )
+
+        cbEvent.assert_called_once_with({
+            'channel': 'SIP',
+            'reloadreason': 'RELOAD (Channel module reload)',
+            'registry_count': '0',
+            'peer_count': '0',
+            'user_count': '0',
+        })
+        self.assertFalse(lose.called)
+
+
+    def test_sendActionOnChannel(self):
+        """Send an action on a channel"""
+
+        channel = self._startAndSpawnChannel()
+        d = channel.sendAction(
+            'Bar',
+            {'key': 'Value', 'key2': 'Value2'}
+        )
+        fields = disassembleMessage(self.transport.value())
+        self.assertEqual(fields['action'], 'Bar')
+        self.assertIn('actionid', fields)
+        self.assertEqual(fields['key'], 'Value')
+        self.assertEqual(fields['key2'], 'Value2')
+        self.assertEqual(fields['channel'], 'Foo/202-0')
+
+
+    def test_originateCEP(self):
+        """Originate a call into a context/exten/priority"""
+
+        self._startAndSpawnChannel()
+        d = self.protocol.originateCEP('Foo/202', 'context', 'exten', 1)
+
+        fields = disassembleMessage(self.transport.value())
+        self.assertEqual(fields['action'], 'Originate')
+        self.assertIn('actionid', fields)
+        self.assertEqual(fields['channel'], 'Foo/202')
+        self.assertEqual(fields['context'], 'context')
+        self.assertEqual(fields['exten'], 'exten')
+        self.assertEqual(fields['priority'], '1')
+        self.assertEqual(fields['async'], 'true')
+
+        cbSuccess = Mock()
+        d.addCallback(cbSuccess)
+
+        self.protocol.dataReceived(
+            'Response: Success\r\n'
+            'ActionID: ' + fields['actionid'] + '\r\n'
+            'Message: Originate successfully queued\r\n'
+            '\r\n'
+        )
+        self.assertEqual(len(cbSuccess.mock_calls), 0)
+
+        self.protocol.dataReceived(
+            'Event: OriginateResponse\r\n'
+            'ActionID: ' + fields['actionid'] + '\r\n'
+            'Channel: Foo/202-0\r\n'
+            'Context: context\r\n'
+            'Exten: exten\r\n'
+            'Priority: 1\r\n'
+            'Response: Success\r\n'
+            'Uniqueid: 1234567890.0\r\n'
+            '\r\n'
+        )
+        self.assertEqual(len(cbSuccess.mock_calls), 1)
+
+
 # vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
